Module beamlit.models.environment_spec
======================================

Classes
-------

`EnvironmentSpec(policies: beamlit.types.Unset | list[str] = <beamlit.types.Unset object>)`
:   Environment specification
    
    Attributes:
        policies (Union[Unset, list[str]]):
    
    Method generated by attrs for class EnvironmentSpec.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `policies: beamlit.types.Unset | list[str]`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :